<?php
namespace calendar\system\event\listener;
use wcf\system\event\IEventListener;
use wcf\data\user\jcoins\statement\UserJcoinsStatementAction;

/**
 * Listen to calendar action for jCoins
 * 
 * @author		Mirco Sarkissian
 * @copyright	2014 Mirco Sarkissian
 * @license		Creative Commons BY-SA <http://creativecommons.org/licenses/by-sa/4.0/>
 * @package		com.ms.calendar.jcoins
 * @subpackage	system.event.listener
 * @category	Community Calendar
 */
class JCoinsMsCalendarListener implements IEventListener {
	/**
	 * @see	wcf\system\event\IEventListener::execute()
	 */
	public function execute($eventObj, $className, $eventName) {
		
		// need module
		if (!MODULE_JCOINS) return;
		
		// need action 'create' or 'update' or 'delete'
		$action = $eventObj->getActionName();
		
		// CREATE
		if ($action == 'create') {
		
			$params = $eventObj->getParameters();
			if (isset($params['data']['decision'])) {
				$decision = $params['data']['decision'];
			}
			else return;
			
			if (isset($params['data']['userID'])) {
				$userID = $params['data']['decision'];
			}
			else return;
			
			if ($decision == 'yes') {
				$sum = JCOINS_RECEIVECOINS_MSDATE_YES;
				$reason = 'wcf.jcoins.statement.dateYes.receive';
			}
			else if ($decision == 'no') {
				$sum = JCOINS_RECEIVECOINS_MSDATE_NO;
				$reason = 'wcf.jcoins.statement.dateNo.receive';
			}
			else return;
			
			$action = new UserJcoinsStatementAction(array(), 'create', array(
					'data' => array(
							'reason' => $reason,
							'sum' => $sum,
							'userID' => $userID
					),
					'changeBalance' => 1
			));
			$action->validateAction();
			$action->executeAction();
		}
		
		// DELETE
		if ($action == 'delete') {
		
			$objects = $eventObj->getObjects();
			foreach ($objects as $object) {
				$userID = $object->userID;
				$decisionOld = $object->decision;
				if ($decisionOld == 'yes') {
					$sum = -1 * JCOINS_RECEIVECOINS_MSDATE_YES;
					$reason = 'wcf.jcoins.statement.dateYesMaybe.receive';
				}
				elseif ($decisionOld == 'no') {
					$sum = -1 * JCOINS_RECEIVECOINS_MSDATE_NO;
					$reason = 'wcf.jcoins.statement.dateNoMaybe.receive';
				}
				else return;
				$this->action($userID, $sum, $reason);
			}
		}
		
		// UPDATE
		if ($action == 'update') {
		
			$objects = $eventObj->getObjects();
			foreach ($objects as $object) {
				$userID = $object->userID;
				$decisionOld = $object->decision;
				$params = $eventObj->getParameters();
				if (isset($params['data']['decision'])) {
					$decisionNew = $params['data']['decision'];
				}
				else continue;
				
				switch ($decisionOld) {
					case 'no':
						if ($decisionNew == 'yes') {
							$sum = JCOINS_RECEIVECOINS_MSDATE_YES - JCOINS_RECEIVECOINS_MSDATE_NO;
							$reason = 'wcf.jcoins.statement.dateNoYes.receive';
						}
						elseif ($decisionNew == 'maybe') {
							$sum = -1 * JCOINS_RECEIVECOINS_MSDATE_NO;
							$reason = 'wcf.jcoins.statement.dateNoMaybe.receive';
						}
						else return;
						$this->action($userID, $sum, $reason);
						break;
						
					case 'maybe':
						if ($decisionNew == 'yes') {
							$sum = JCOINS_RECEIVECOINS_MSDATE_YES;
							$reason = 'wcf.jcoins.statement.dateYes.receive';
						}
						elseif ($decisionNew == 'no') {
							$sum = JCOINS_RECEIVECOINS_MSDATE_NO;
							$reason = 'wcf.jcoins.statement.dateNo.receive';
						}
						else return;
						$this->action($userID, $sum, $reason);
						break;
							
					case 'yes':
						if ($decisionNew == 'no') {
							$sum = JCOINS_RECEIVECOINS_MSDATE_NO - JCOINS_RECEIVECOINS_MSDATE_YES;
							$reason = 'wcf.jcoins.statement.dateYesNo.receive';
						}
						elseif ($decisionNew == 'maybe') {
							$sum = -1 * JCOINS_RECEIVECOINS_MSDATE_YES;
							$reason = 'wcf.jcoins.statement.dateYesMaybe.receive';
						}
						else return;
						$this->action($userID, $sum, $reason);
						break;
				}
			}
		}
	}
	
	protected function action($userID, $sum, $reason) {
		$action = new UserJcoinsStatementAction(array(), 'create', array(
			'data' => array(
					'reason' => $reason,
					'sum' => $sum,
					'userID' => $userID
			),
			'changeBalance' => 1
		));
		$action->validateAction();
		$action->executeAction();
	}
}
